|pypi| |actions| |coverage|

edc-protocol
------------

TODO: Add back features to manage enrollment caps per subject types, if this is still where to do it


.. |pypi| image:: https://img.shields.io/pypi/v/edc-protocol.svg
    :target: https://pypi.python.org/pypi/edc-protocol

.. |actions| image:: https://github.com/clinicedc/edc-protocol/workflows/build/badge.svg?branch=develop
  :target: https://github.com/clinicedc/edc-protocol/actions?query=workflow:build

.. |coverage| image:: https://coveralls.io/repos/github/clinicedc/edc-protocol/badge.svg?branch=develop
    :target: https://coveralls.io/github/clinicedc/edc-protocol?branch=develop
